aboutsummaryrefslogtreecommitdiffstats
path: root/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistence.java
diff options
context:
space:
mode:
Diffstat (limited to 'policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistence.java')
-rw-r--r--policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistence.java51
1 files changed, 48 insertions, 3 deletions
diff --git a/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistence.java b/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistence.java
index 32852225..ee1e8b52 100644
--- a/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistence.java
+++ b/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistence.java
@@ -67,6 +67,14 @@ public interface SystemPersistence {
boolean backupController(String controllerName);
/**
+ * backs up a topic configuration.
+ *
+ * @param topicName the controller name
+ * @return true if the configuration is backed up
+ */
+ boolean backupTopic(String topicName);
+
+ /**
* persists controller configuration.
*
* @param controllerName the controller name
@@ -79,6 +87,18 @@ public interface SystemPersistence {
boolean storeController(String controllerName, Object configuration);
/**
+ * persists topic configuration.
+ *
+ * @param topicName the controller name
+ * @param configuration object containing the configuration
+ *
+ * @return true if storage is succesful, false otherwise
+ * @throws IllegalArgumentException if the configuration cannot be handled by the persistence
+ * manager
+ */
+ boolean storeTopic(String topicName, Object configuration);
+
+ /**
* delete controller configuration.
*
* @param controllerName the controller name
@@ -87,6 +107,21 @@ public interface SystemPersistence {
boolean deleteController(String controllerName);
/**
+ * delete topic configuration.
+ *
+ * @param topicName the topic name
+ * @return true if storage is succesful, false otherwise
+ */
+ boolean deleteTopic(String topicName);
+
+ /**
+ * get controllers configuration.
+ *
+ * @return list of controllers properties
+ */
+ List<Properties> getControllerProperties();
+
+ /**
* get controller properties.
*
* @param controllerName controller name
@@ -98,11 +133,21 @@ public interface SystemPersistence {
Properties getControllerProperties(String controllerName);
/**
* get controllers configuration.
*
* @return list of controllers properties
*/
- List<Properties> getControllerProperties();
+ List<Properties> getTopicProperties();
+
+ /**
+ * get topic properties.
+ *
+ * @param topicName topic name
+ * @return properties for this topic
+ *
+ * @throws IllegalArgumentException if topicName is invalid
+ */
+ Properties getTopicProperties(String topicName);
/**
* get environments.
@@ -98,11 +133,21 @@ public interface SystemPersistence {
Properties getControllerProperties(String controllerName);
/**
- * get controllers configuration.
+ * get topic configuration.
*
@@ -98,11 +133,21 @@ public interface SystemPersistence {
*
- * @return list of controllers properties
+ * @return list of topic properties
*/